You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tinkerpop.apache.org by sp...@apache.org on 2015/02/12 14:02:29 UTC

[63/77] incubator-tinkerpop git commit: replaced namespace com.tinkerpop with org.apache.tinkerpop

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SubgraphStrategy.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/process/graph/step/sideEffect/StrategyGraphStep.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/process/graph/step/sideEffect/StrategyGraphStep.java
index af247a9..af415f6 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/process/graph/step/sideEffect/StrategyGraphStep.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/process/graph/step/sideEffect/StrategyGraphStep.java
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy.process.graph.step.sideEffect;
+package org.apache.tinkerpop.gremlin.structure.strategy.process.graph.step.sideEffect;
 
-import com.tinkerpop.gremlin.process.Traversal;
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.process.graph.traversal.step.sideEffect.GraphStep;
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.strategy.StrategyEdge;
-import com.tinkerpop.gremlin.structure.strategy.StrategyGraph;
-import com.tinkerpop.gremlin.structure.strategy.StrategyVertex;
+import org.apache.tinkerpop.gremlin.process.Traversal;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.step.sideEffect.GraphStep;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.strategy.StrategyEdge;
+import org.apache.tinkerpop.gremlin.structure.strategy.StrategyGraph;
+import org.apache.tinkerpop.gremlin.structure.strategy.StrategyVertex;
 
 import java.util.Iterator;
 

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/Comparators.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/Comparators.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/Comparators.java
index cabe682..657c9c7 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/Comparators.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/Comparators.java
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util;
+package org.apache.tinkerpop.gremlin.structure.util;
 
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
 
 import java.util.Comparator;
 import java.util.Map;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/ElementHelper.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/FeatureDescriptor.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/FeatureDescriptor.java
index 01e9c70..232444d 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/FeatureDescriptor.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/FeatureDescriptor.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util;
+package org.apache.tinkerpop.gremlin.structure.util;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphFactory.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphVariableHelper.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphVariableHelper.java
index 46a22ce..f7e251c 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphVariableHelper.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphVariableHelper.java
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util;
+package org.apache.tinkerpop.gremlin.structure.util;
 
-import com.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Graph;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/StringFactory.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchFeatures.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchFeatures.java
index 3ab0e79..7c9a533 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchFeatures.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchFeatures.java
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch;
+package org.apache.tinkerpop.gremlin.structure.util.batch;
 
-import com.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Graph;
 
 /**
  * @author Stephen Mallette (http://stephen.genoprime.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/Exists.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/Exists.java
index 08d5ee1..ebe941e 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/Exists.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/Exists.java
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch;
+package org.apache.tinkerpop.gremlin.structure.util.batch;
 
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
 
 import java.util.function.BiConsumer;
 

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/VertexIdType.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/VertexIdType.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/VertexIdType.java
index 30eb2f8..29cf4ce 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/VertexIdType.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/VertexIdType.java
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch;
+package org.apache.tinkerpop.gremlin.structure.util.batch;
 
-import com.tinkerpop.gremlin.structure.util.batch.cache.LongIDVertexCache;
-import com.tinkerpop.gremlin.structure.util.batch.cache.ObjectIDVertexCache;
-import com.tinkerpop.gremlin.structure.util.batch.cache.StringIDVertexCache;
-import com.tinkerpop.gremlin.structure.util.batch.cache.URLCompression;
-import com.tinkerpop.gremlin.structure.util.batch.cache.VertexCache;
+import org.apache.tinkerpop.gremlin.structure.util.batch.cache.LongIDVertexCache;
+import org.apache.tinkerpop.gremlin.structure.util.batch.cache.ObjectIDVertexCache;
+import org.apache.tinkerpop.gremlin.structure.util.batch.cache.StringIDVertexCache;
+import org.apache.tinkerpop.gremlin.structure.util.batch.cache.URLCompression;
+import org.apache.tinkerpop.gremlin.structure.util.batch.cache.VertexCache;
 
 /**
  * Type of vertex ids expected by BatchGraph. The default is IdType.OBJECT.

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/AbstractIDVertexCache.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/AbstractIDVertexCache.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/AbstractIDVertexCache.java
index 4dbb618..5672842 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/AbstractIDVertexCache.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/AbstractIDVertexCache.java
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch.cache;
+package org.apache.tinkerpop.gremlin.structure.util.batch.cache;
 
-import com.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
 
 import java.util.HashMap;
 import java.util.HashSet;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/LongIDVertexCache.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/LongIDVertexCache.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/LongIDVertexCache.java
index 885eb9b..aef4a72 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/LongIDVertexCache.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/LongIDVertexCache.java
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch.cache;
+package org.apache.tinkerpop.gremlin.structure.util.batch.cache;
 
 import com.carrotsearch.hppc.LongArrayList;
 import com.carrotsearch.hppc.LongObjectMap;
 import com.carrotsearch.hppc.LongObjectOpenHashMap;
 import com.carrotsearch.hppc.procedures.LongProcedure;
-import com.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
 
 /**
  * @author Matthias Broecheler (http://www.matthiasb.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/ObjectIDVertexCache.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/ObjectIDVertexCache.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/ObjectIDVertexCache.java
index 95e2150..7487430 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/ObjectIDVertexCache.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/ObjectIDVertexCache.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch.cache;
+package org.apache.tinkerpop.gremlin.structure.util.batch.cache;
 
 /**
  * @author Matthias Broecheler (http://www.matthiasb.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringCompression.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringCompression.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringCompression.java
index ee04a59..c862f71 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringCompression.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringCompression.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch.cache;
+package org.apache.tinkerpop.gremlin.structure.util.batch.cache;
 
 /**
  * @author Matthias Broecheler (http://www.matthiasb.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringIDVertexCache.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringIDVertexCache.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringIDVertexCache.java
index b69c958..865fd70 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringIDVertexCache.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/StringIDVertexCache.java
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch.cache;
+package org.apache.tinkerpop.gremlin.structure.util.batch.cache;
 
-import com.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
 
 import java.util.HashMap;
 import java.util.HashSet;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/URLCompression.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/URLCompression.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/URLCompression.java
index f06ef73..4113cc7 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/URLCompression.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/URLCompression.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch.cache;
+package org.apache.tinkerpop.gremlin.structure.util.batch.cache;
 
 import java.util.HashMap;
 import java.util.Map;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/VertexCache.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/VertexCache.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/VertexCache.java
index 32b5bc5..3ee7626 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/VertexCache.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/cache/VertexCache.java
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch.cache;
+package org.apache.tinkerpop.gremlin.structure.util.batch.cache;
 
-import com.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
 
 /**
  * @author Matthias Broecheler (http://www.matthiasb.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/Attachable.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/Attachable.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/Attachable.java
index fe62ffb..c07a3ec 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/Attachable.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/Attachable.java
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.detached;
+package org.apache.tinkerpop.gremlin.structure.util.detached;
 
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
 
 /**
  * An interface that provides methods for detached properties and elements to be re-attached to the {@link Graph}.

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedEdge.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedElement.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedElement.java
index 4acdcc9..e8da1a1 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedElement.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedElement.java
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.detached;
+package org.apache.tinkerpop.gremlin.structure.util.detached;
 
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
 
 import java.io.Serializable;
 import java.util.Collections;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedFactory.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedFactory.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedFactory.java
index 09c0654..12c3a73 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedFactory.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedFactory.java
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.detached;
+package org.apache.tinkerpop.gremlin.structure.util.detached;
 
-import com.tinkerpop.gremlin.process.Path;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.process.Path;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedPath.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedPath.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedPath.java
index dd8cf4a..1709512 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedPath.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedPath.java
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.detached;
+package org.apache.tinkerpop.gremlin.structure.util.detached;
 
-import com.tinkerpop.gremlin.process.Path;
-import com.tinkerpop.gremlin.process.util.path.MutablePath;
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.process.Path;
+import org.apache.tinkerpop.gremlin.process.util.path.MutablePath;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedProperty.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedProperty.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedProperty.java
index 21a5b1b..e09039f 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedProperty.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedProperty.java
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.detached;
-
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
+package org.apache.tinkerpop.gremlin.structure.util.detached;
+
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
 
 import java.io.Serializable;
 

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertex.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertex.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertex.java
index d7f450b..2517986 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertex.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertex.java
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.detached;
-
-import com.tinkerpop.gremlin.process.T;
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
+package org.apache.tinkerpop.gremlin.structure.util.detached;
+
+import org.apache.tinkerpop.gremlin.process.T;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
 
 import java.util.ArrayList;
 import java.util.HashMap;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertexProperty.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertexProperty.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertexProperty.java
index ab4562b..fddbc0d 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertexProperty.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedVertexProperty.java
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.detached;
-
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.util.iterator.IteratorUtils;
+package org.apache.tinkerpop.gremlin.structure.util.detached;
+
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.util.iterator.IteratorUtils;
 
 import java.util.Collections;
 import java.util.HashMap;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyGraph.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyGraph.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyGraph.java
index cd7a2b5..37070b5 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyGraph.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyGraph.java
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.empty;
-
-import com.tinkerpop.gremlin.process.Traversal;
-import com.tinkerpop.gremlin.process.computer.GraphComputer;
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.process.graph.traversal.util.EmptyGraphTraversal;
-import com.tinkerpop.gremlin.process.traversal.util.EmptyTraversal;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Transaction;
-import com.tinkerpop.gremlin.structure.Vertex;
+package org.apache.tinkerpop.gremlin.structure.util.empty;
+
+import org.apache.tinkerpop.gremlin.process.Traversal;
+import org.apache.tinkerpop.gremlin.process.computer.GraphComputer;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.util.EmptyGraphTraversal;
+import org.apache.tinkerpop.gremlin.process.traversal.util.EmptyTraversal;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Transaction;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
 import org.apache.commons.configuration.Configuration;
 
 import java.util.Collections;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyProperty.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyProperty.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyProperty.java
index 5a62dc8..4450ea0 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyProperty.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyProperty.java
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.empty;
+package org.apache.tinkerpop.gremlin.structure.util.empty;
 
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
 
 import java.util.NoSuchElementException;
 

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyVertexProperty.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyVertexProperty.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyVertexProperty.java
index d8eb6fd..abd1548 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyVertexProperty.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/empty/EmptyVertexProperty.java
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.empty;
+package org.apache.tinkerpop.gremlin.structure.util.empty;
 
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
 
 import java.util.Collections;
 import java.util.Iterator;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedEdge.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedEdge.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedEdge.java
index 10b5035..f48c7fc 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedEdge.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedEdge.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.wrapped;
+package org.apache.tinkerpop.gremlin.structure.util.wrapped;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedElement.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedElement.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedElement.java
index d8aba7e..573d0bb 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedElement.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedElement.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.wrapped;
+package org.apache.tinkerpop.gremlin.structure.util.wrapped;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedGraph.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedGraph.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedGraph.java
index dc5e6a4..004bdb6 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedGraph.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedGraph.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.wrapped;
+package org.apache.tinkerpop.gremlin.structure.util.wrapped;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedProperty.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedProperty.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedProperty.java
index b56a825..454e9a1 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedProperty.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedProperty.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.wrapped;
+package org.apache.tinkerpop.gremlin.structure.util.wrapped;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVariables.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVariables.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVariables.java
index 3673f4e..31f6f84 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVariables.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVariables.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.wrapped;
+package org.apache.tinkerpop.gremlin.structure.util.wrapped;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertex.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertex.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertex.java
index 13e4293..77fabe6 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertex.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertex.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.wrapped;
+package org.apache.tinkerpop.gremlin.structure.util.wrapped;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertexProperty.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertexProperty.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertexProperty.java
index 068d861..8003921 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertexProperty.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/wrapped/WrappedVertexProperty.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.wrapped;
+package org.apache.tinkerpop.gremlin.structure.util.wrapped;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Gremlin.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Gremlin.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Gremlin.java
index fb4b55e..26f9919 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Gremlin.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Gremlin.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util;
+package org.apache.tinkerpop.gremlin.util;
 
 import com.jcabi.manifests.Manifests;
 

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Serializer.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Serializer.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Serializer.java
index 747b5e7..22dba7a 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Serializer.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/Serializer.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util;
+package org.apache.tinkerpop.gremlin.util;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/StreamFactory.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/StreamFactory.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/StreamFactory.java
index 5c84ff9..e905d92 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/StreamFactory.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/StreamFactory.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util;
+package org.apache.tinkerpop.gremlin.util;
 
 import java.util.Iterator;
 import java.util.Spliterator;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/TimeUtil.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/TimeUtil.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/TimeUtil.java
index f4c8744..5131560 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/TimeUtil.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/TimeUtil.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util;
+package org.apache.tinkerpop.gremlin.util;
 
 import java.util.concurrent.TimeUnit;
 

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/config/YamlConfiguration.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/config/YamlConfiguration.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/config/YamlConfiguration.java
index 77f80f2..56ae2ea 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/config/YamlConfiguration.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/config/YamlConfiguration.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.config;
+package org.apache.tinkerpop.gremlin.util.config;
 
 import org.apache.commons.configuration.AbstractHierarchicalFileConfiguration;
 import org.apache.commons.configuration.ConfigurationException;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ArrayListSupplier.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ArrayListSupplier.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ArrayListSupplier.java
index ac694a9..31267ee 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ArrayListSupplier.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ArrayListSupplier.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 import java.io.Serializable;
 import java.util.ArrayList;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/BulkSetSupplier.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/BulkSetSupplier.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/BulkSetSupplier.java
index 0c5d25c..f524a3b 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/BulkSetSupplier.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/BulkSetSupplier.java
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
-import com.tinkerpop.gremlin.process.util.BulkSet;
+import org.apache.tinkerpop.gremlin.process.util.BulkSet;
 
 import java.io.Serializable;
 import java.util.function.Supplier;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/CloningUnaryOperator.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/CloningUnaryOperator.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/CloningUnaryOperator.java
index 51f9bf2..85df187 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/CloningUnaryOperator.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/CloningUnaryOperator.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 import java.io.Serializable;
 import java.util.HashMap;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ConstantSupplier.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ConstantSupplier.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ConstantSupplier.java
index 5f2ee81..af2a839 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ConstantSupplier.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ConstantSupplier.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 import java.io.Serializable;
 import java.util.function.Supplier;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/FunctionUtils.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/FunctionUtils.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/FunctionUtils.java
index 14e006e..1071f0d 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/FunctionUtils.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/FunctionUtils.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 import java.util.function.BiConsumer;
 import java.util.function.Consumer;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashMapSupplier.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashMapSupplier.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashMapSupplier.java
index ca44bff..e72c54b 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashMapSupplier.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashMapSupplier.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 import java.io.Serializable;
 import java.util.HashMap;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashSetSupplier.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashSetSupplier.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashSetSupplier.java
index 7447bef..579b17e 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashSetSupplier.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/HashSetSupplier.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 import java.io.Serializable;
 import java.util.HashSet;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/MeanNumberSupplier.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/MeanNumberSupplier.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/MeanNumberSupplier.java
index ec94d16..08d419e 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/MeanNumberSupplier.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/MeanNumberSupplier.java
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)
  */
 
-import com.tinkerpop.gremlin.process.graph.traversal.step.map.MeanStep;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.step.map.MeanStep;
 
 import java.io.Serializable;
 import java.util.function.Supplier;

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingBiConsumer.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingBiConsumer.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingBiConsumer.java
index ca4cf68..6a0184a 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingBiConsumer.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingBiConsumer.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 /**
  * @author Stephen Mallette (http://stephen.genoprime.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingConsumer.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingConsumer.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingConsumer.java
index db0ab12..a42cb18 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingConsumer.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingConsumer.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 /**
  * @author Stephen Mallette (http://stephen.genoprime.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingFunction.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingFunction.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingFunction.java
index 86662a9..10655f1 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingFunction.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingFunction.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 /**
  * @author Stephen Mallette (http://stephen.genoprime.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingSupplier.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingSupplier.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingSupplier.java
index 57e93fe..b9cf562 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingSupplier.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/ThrowingSupplier.java
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
 /**
  * @author Stephen Mallette (http://stephen.genoprime.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/TraversableLambda.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/TraversableLambda.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/TraversableLambda.java
index 736866d..8373f5a 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/TraversableLambda.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/util/function/TraversableLambda.java
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.util.function;
+package org.apache.tinkerpop.gremlin.util.function;
 
-import com.tinkerpop.gremlin.process.Traversal;
+import org.apache.tinkerpop.gremlin.process.Traversal;
 
 /**
  * @author Marko A. Rodriguez (http://markorodriguez.com)
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SubgraphStrategy.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SubgraphStrategy.java
index 73e6170..c8e8bd5 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SubgraphStrategy.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/SubgraphStrategy.java
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.strategy;
+package org.apache.tinkerpop.gremlin.structure.strategy;
 
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.util.StreamFactory;
-import com.tinkerpop.gremlin.util.iterator.IteratorUtils;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.util.StreamFactory;
+import org.apache.tinkerpop.gremlin.util.iterator.IteratorUtils;
 
 import java.util.Iterator;
 import java.util.function.BiFunction;
@@ -35,7 +35,7 @@ import java.util.function.UnaryOperator;
 
 /**
  * A {@link GraphStrategy} which creates a logical subgraph to selectively include vertices and edges of a
  * {@link com.tinkerpop.gremlin.structure.Graph} according to provided criteria.  A vertex is in the subgraph if
  * it meets the specified {@link #vertexPredicate}.  An edge is in the subgraph if it meets the specified
  * {@link #edgePredicate} and its associated vertices meet the specified {@link #vertexPredicate}.
  *

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/strategy/process/graph/step/sideEffect/StrategyGraphStep.java
----------------------------------------------------------------------
@@ -35,7 +35,7 @@ import java.util.function.UnaryOperator;
 /**
  * A {@link GraphStrategy} which creates a logical subgraph to selectively include vertices and edges of a
- * {@link com.tinkerpop.gremlin.structure.Graph} according to provided criteria.  A vertex is in the subgraph if
+ * {@link org.apache.tinkerpop.gremlin.structure.Graph} according to provided criteria.  A vertex is in the subgraph if
  * it meets the specified {@link #vertexPredicate}.  An edge is in the subgraph if it meets the specified
  * {@link #edgePredicate} and its associated vertices meet the specified {@link #vertexPredicate}.
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/ElementHelper.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/ElementHelper.java
index f057037..e3d8799 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/ElementHelper.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/ElementHelper.java
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util;
-
-import com.tinkerpop.gremlin.process.T;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
+package org.apache.tinkerpop.gremlin.structure.util;
+
+import org.apache.tinkerpop.gremlin.process.T;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
 import org.javatuples.Pair;
 
 import java.util.ArrayList;
@@ -41,7 +41,7 @@ import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
 /**
  * Utility class supporting common functions for {@link com.tinkerpop.gremlin.structure.Element}.
  *
  * @author Marko A. Rodriguez (http://markorodriguez.com)
  * @author Stephen Mallette (http://stephen.genoprime.com)
@@ -107,7 +107,7 @@ public final class ElementHelper {
 
     /**
      * Determines whether a list of key/values are legal, ensuring that there are an even number of values submitted
      * and that the key values in the list of arguments are {@link String} or {@link com.tinkerpop.gremlin.structure.Element} objects.
      *
      * @param propertyKeyValues a list of key/value pairs
      * @throws IllegalArgumentException if something in the pairs is illegal
@@ -122,11 +122,11 @@ public final class ElementHelper {
     }
 
     /**
      * Extracts the value of the {@link com.tinkerpop.gremlin.process.T#id} key from the list of arguments.
      *
      * @param keyValues a list of key/value pairs
-     * @return the value associated with {@link com.tinkerpop.gremlin.process.T#id}
-     * @throws NullPointerException if the value for the {@link com.tinkerpop.gremlin.process.T#id} key is {@code null}
+     * @return the value associated with {@link org.apache.tinkerpop.gremlin.process.T#id}
+     * @throws NullPointerException if the value for the {@link org.apache.tinkerpop.gremlin.process.T#id} key is {@code null}
      */
     public static Optional<Object> getIdValue(final Object... keyValues) {
         for (int i = 0; i < keyValues.length; i = i + 2) {
@@ -216,12 +216,12 @@ public final class ElementHelper {
     }
 
     /**
      * Extracts the value of the {@link com.tinkerpop.gremlin.process.T#label} key from the list of arguments.
      *
      * @param keyValues a list of key/value pairs
-     * @return the value associated with {@link com.tinkerpop.gremlin.process.T#label}
+     * @return the value associated with {@link org.apache.tinkerpop.gremlin.process.T#label}
      * @throws ClassCastException   if the value of the label is not a {@link String}
-     * @throws NullPointerException if the value for the {@link com.tinkerpop.gremlin.process.T#label} key is {@code null}
+     * @throws NullPointerException if the value for the {@link org.apache.tinkerpop.gremlin.process.T#label} key is {@code null}
      */
     public static Optional<String> getLabelValue(final Object... keyValues) {
         for (int i = 0; i < keyValues.length; i = i + 2) {
@@ -234,8 +234,8 @@ public final class ElementHelper {
     }
 
     /**
      * Assign key/value pairs as properties to an {@link com.tinkerpop.gremlin.structure.Element}.  If the value of {@link com.tinkerpop.gremlin.process.T#id} or
      * {@link com.tinkerpop.gremlin.process.T#label} is in the set of pairs, then they are ignored.
      *
      * @param element           the graph element to assign the {@code propertyKeyValues}
      * @param propertyKeyValues the key/value pairs to assign to the {@code element}
@@ -253,8 +253,8 @@ public final class ElementHelper {
     }
 
     /**
      * Assign key/value pairs as properties to an {@link com.tinkerpop.gremlin.structure.Vertex}.  If the value of {@link com.tinkerpop.gremlin.process.T#id} or
      * {@link com.tinkerpop.gremlin.process.T#label} is in the set of pairs, then they are ignored.
      *
      * @param vertex            the vertex to assign the {@code propertyKeyValues}
      * @param propertyKeyValues the key/value pairs to assign to the {@code vertex}
@@ -301,11 +301,11 @@ public final class ElementHelper {
     }
 
     /**
      * A standard method for determining if two {@link com.tinkerpop.gremlin.structure.Element} objects are equal. This method should be used by any
      * {@link Object#equals(Object)} implementation to ensure consistent behavior. This method is used for Vertex, Edge, and VertexProperty.
      *
      * @param a The first {@link com.tinkerpop.gremlin.structure.Element}
      * @param b The second {@link com.tinkerpop.gremlin.structure.Element} (as an {@link Object})
      * @return true if elements and equal and false otherwise
      * @throws IllegalArgumentException if either argument is null
      */
@@ -325,11 +325,11 @@ public final class ElementHelper {
     }
 
     /**
      * A standard method for determining if two {@link com.tinkerpop.gremlin.structure.VertexProperty} objects are equal. This method should be used by any
      * {@link Object#equals(Object)} implementation to ensure consistent behavior.
      *
-     * @param a the first {@link com.tinkerpop.gremlin.structure.VertexProperty}
-     * @param b the second {@link com.tinkerpop.gremlin.structure.VertexProperty}
+     * @param a the first {@link org.apache.tinkerpop.gremlin.structure.VertexProperty}
+     * @param b the second {@link org.apache.tinkerpop.gremlin.structure.VertexProperty}
      * @return true if equal and false otherwise
      */
     public static boolean areEqual(final VertexProperty a, final Object b) {
@@ -337,10 +337,10 @@ public final class ElementHelper {
     }
 
     /**
      * Simply tests if the value returned from {@link com.tinkerpop.gremlin.structure.Element#id()} are {@code equal()}.
      *
-     * @param a the first {@link com.tinkerpop.gremlin.structure.Element}
-     * @param b the second {@link com.tinkerpop.gremlin.structure.Element}
+     * @param a the first {@link org.apache.tinkerpop.gremlin.structure.Element}
+     * @param b the second {@link org.apache.tinkerpop.gremlin.structure.Element}
      * @return true if ids are equal and false otherwise
      */
     public static boolean haveEqualIds(final Element a, final Element b) {
@@ -359,7 +359,7 @@ public final class ElementHelper {
 
     /**
      * If two {@link Property} instances are equal, then they must have the same hash codes. This methods ensures consistent hashCode values.
-     * For {@link VertexProperty} use {@link ElementHelper#hashCode(com.tinkerpop.gremlin.structure.Element)}.
+     * For {@link VertexProperty} use {@link ElementHelper#hashCode(org.apache.tinkerpop.gremlin.structure.Element)}.
      *
      * @param property the property to get the hashCode for
      * @return the hash code of the property
@@ -369,11 +369,11 @@ public final class ElementHelper {
     }
 
     /**
      * A standard method for determining if two {@link com.tinkerpop.gremlin.structure.Property} objects are equal. This method should be used by any
      * {@link Object#equals(Object)} implementation to ensure consistent behavior.
      *
-     * @param a the first {@link com.tinkerpop.gremlin.structure.Property}
-     * @param b the second {@link com.tinkerpop.gremlin.structure.Property}
+     * @param a the first {@link org.apache.tinkerpop.gremlin.structure.Property}
+     * @param b the second {@link org.apache.tinkerpop.gremlin.structure.Property}
      * @return true if equal and false otherwise
      */
     public static boolean areEqual(final Property a, final Object b) {

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/FeatureDescriptor.java
----------------------------------------------------------------------
@@ -41,7 +41,7 @@ import java.util.stream.IntStream;
 
 /**
- * Utility class supporting common functions for {@link com.tinkerpop.gremlin.structure.Element}.
+ * Utility class supporting common functions for {@link org.apache.tinkerpop.gremlin.structure.Element}.
  *
  * @author Marko A. Rodriguez (http://markorodriguez.com)
@@ -107,7 +107,7 @@ public final class ElementHelper {
     /**
      * Determines whether a list of key/values are legal, ensuring that there are an even number of values submitted
-     * and that the key values in the list of arguments are {@link String} or {@link com.tinkerpop.gremlin.structure.Element} objects.
+     * and that the key values in the list of arguments are {@link String} or {@link org.apache.tinkerpop.gremlin.structure.Element} objects.
      *
      * @param propertyKeyValues a list of key/value pairs
@@ -122,11 +122,11 @@ public final class ElementHelper {
 
     /**
-     * Extracts the value of the {@link com.tinkerpop.gremlin.process.T#id} key from the list of arguments.
+     * Extracts the value of the {@link org.apache.tinkerpop.gremlin.process.T#id} key from the list of arguments.
      *
      * @param keyValues a list of key/value pairs
@@ -216,12 +216,12 @@ public final class ElementHelper {
 
     /**
-     * Extracts the value of the {@link com.tinkerpop.gremlin.process.T#label} key from the list of arguments.
+     * Extracts the value of the {@link org.apache.tinkerpop.gremlin.process.T#label} key from the list of arguments.
      *
      * @param keyValues a list of key/value pairs
@@ -234,8 +234,8 @@ public final class ElementHelper {
 
     /**
-     * Assign key/value pairs as properties to an {@link com.tinkerpop.gremlin.structure.Element}.  If the value of {@link com.tinkerpop.gremlin.process.T#id} or
-     * {@link com.tinkerpop.gremlin.process.T#label} is in the set of pairs, then they are ignored.
+     * Assign key/value pairs as properties to an {@link org.apache.tinkerpop.gremlin.structure.Element}.  If the value of {@link org.apache.tinkerpop.gremlin.process.T#id} or
+     * {@link org.apache.tinkerpop.gremlin.process.T#label} is in the set of pairs, then they are ignored.
      *
      * @param element           the graph element to assign the {@code propertyKeyValues}
@@ -253,8 +253,8 @@ public final class ElementHelper {
 
     /**
-     * Assign key/value pairs as properties to an {@link com.tinkerpop.gremlin.structure.Vertex}.  If the value of {@link com.tinkerpop.gremlin.process.T#id} or
-     * {@link com.tinkerpop.gremlin.process.T#label} is in the set of pairs, then they are ignored.
+     * Assign key/value pairs as properties to an {@link org.apache.tinkerpop.gremlin.structure.Vertex}.  If the value of {@link org.apache.tinkerpop.gremlin.process.T#id} or
+     * {@link org.apache.tinkerpop.gremlin.process.T#label} is in the set of pairs, then they are ignored.
      *
      * @param vertex            the vertex to assign the {@code propertyKeyValues}
@@ -301,11 +301,11 @@ public final class ElementHelper {
 
     /**
-     * A standard method for determining if two {@link com.tinkerpop.gremlin.structure.Element} objects are equal. This method should be used by any
+     * A standard method for determining if two {@link org.apache.tinkerpop.gremlin.structure.Element} objects are equal. This method should be used by any
      * {@link Object#equals(Object)} implementation to ensure consistent behavior. This method is used for Vertex, Edge, and VertexProperty.
      *
@@ -301,11 +301,11 @@ public final class ElementHelper {
      * {@link Object#equals(Object)} implementation to ensure consistent behavior. This method is used for Vertex, Edge, and VertexProperty.
      *
-     * @param a The first {@link com.tinkerpop.gremlin.structure.Element}
-     * @param b The second {@link com.tinkerpop.gremlin.structure.Element} (as an {@link Object})
+     * @param a The first {@link org.apache.tinkerpop.gremlin.structure.Element}
+     * @param b The second {@link org.apache.tinkerpop.gremlin.structure.Element} (as an {@link Object})
      * @return true if elements and equal and false otherwise
      * @throws IllegalArgumentException if either argument is null
@@ -325,11 +325,11 @@ public final class ElementHelper {
 
     /**
-     * A standard method for determining if two {@link com.tinkerpop.gremlin.structure.VertexProperty} objects are equal. This method should be used by any
+     * A standard method for determining if two {@link org.apache.tinkerpop.gremlin.structure.VertexProperty} objects are equal. This method should be used by any
      * {@link Object#equals(Object)} implementation to ensure consistent behavior.
      *
@@ -337,10 +337,10 @@ public final class ElementHelper {
 
     /**
-     * Simply tests if the value returned from {@link com.tinkerpop.gremlin.structure.Element#id()} are {@code equal()}.
+     * Simply tests if the value returned from {@link org.apache.tinkerpop.gremlin.structure.Element#id()} are {@code equal()}.
      *
@@ -369,11 +369,11 @@ public final class ElementHelper {
 
     /**
-     * A standard method for determining if two {@link com.tinkerpop.gremlin.structure.Property} objects are equal. This method should be used by any
+     * A standard method for determining if two {@link org.apache.tinkerpop.gremlin.structure.Property} objects are equal. This method should be used by any
      * {@link Object#equals(Object)} implementation to ensure consistent behavior.
      *
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphFactory.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphFactory.java
index af8c383..29be657 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphFactory.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphFactory.java
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util;
+package org.apache.tinkerpop.gremlin.structure.util;
 
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.util.config.YamlConfiguration;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.util.config.YamlConfiguration;
 import org.apache.commons.configuration.Configuration;
 import org.apache.commons.configuration.ConfigurationException;
 import org.apache.commons.configuration.MapConfiguration;
@@ -30,7 +30,7 @@ import java.io.File;
 import java.util.Map;
 
 /**
  * Factory to construct new {@link com.tinkerpop.gremlin.structure.Graph} instances from a
  * {@link org.apache.commons.configuration.Configuration} object or properties file.
  *
  * @author Stephen Mallette (http://stephen.genoprime.com)
@@ -38,12 +38,12 @@ import java.util.Map;
 public class GraphFactory {
 
     /**
      * Open a graph.  See each {@link com.tinkerpop.gremlin.structure.Graph} instance for its configuration options.
      *
      * @param configuration A configuration object that specifies the minimally required properties for a                        I
      *                      {@link com.tinkerpop.gremlin.structure.Graph} instance. This minimum is determined by the
      *                      {@link com.tinkerpop.gremlin.structure.Graph} instance itself.
      * @return A {@link com.tinkerpop.gremlin.structure.Graph} instance.
      * @throws IllegalArgumentException if {@code configuration}
      */
     public static Graph open(final Configuration configuration) {
@@ -76,14 +76,14 @@ public class GraphFactory {
     }
 
     /**
      * Open a graph.  See each {@link com.tinkerpop.gremlin.structure.Graph} instance for its configuration options. This file may be XML, YAML,
      * or a standard properties file. How the configuration is used (and which kind is required) is dependent on
      * the implementation.
      *
      * @param configurationFile The location of a configuration file that specifies the minimally required properties
      *                          for a {@link com.tinkerpop.gremlin.structure.Graph} instance. This minimum is determined by the {@link com.tinkerpop.gremlin.structure.Graph} instance
      *                          itself.
-     * @return A {@link com.tinkerpop.gremlin.structure.Graph} instance.
+     * @return A {@link org.apache.tinkerpop.gremlin.structure.Graph} instance.
      * @throws IllegalArgumentException if {@code configurationFile} is null
      */
     public static Graph open(final String configurationFile) {
@@ -92,7 +92,7 @@ public class GraphFactory {
     }
 
     /**
      * Open a graph. See each {@link com.tinkerpop.gremlin.structure.Graph} instance for its configuration options.
      *
      * @param configuration A {@link java.util.Map} based configuration that will be converted to an {@link org.apache.commons.configuration.Configuration} object
      *                      via {@link org.apache.commons.configuration.MapConfiguration} and passed to the appropriate overload.

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/GraphVariableHelper.java
----------------------------------------------------------------------
@@ -30,7 +30,7 @@ import java.io.File;
 
 /**
- * Factory to construct new {@link com.tinkerpop.gremlin.structure.Graph} instances from a
+ * Factory to construct new {@link org.apache.tinkerpop.gremlin.structure.Graph} instances from a
  * {@link org.apache.commons.configuration.Configuration} object or properties file.
  *
@@ -38,12 +38,12 @@ import java.util.Map;
 
     /**
-     * Open a graph.  See each {@link com.tinkerpop.gremlin.structure.Graph} instance for its configuration options.
+     * Open a graph.  See each {@link org.apache.tinkerpop.gremlin.structure.Graph} instance for its configuration options.
      *
      * @param configuration A configuration object that specifies the minimally required properties for a                        I
@@ -38,12 +38,12 @@ import java.util.Map;
      *
      * @param configuration A configuration object that specifies the minimally required properties for a                        I
-     *                      {@link com.tinkerpop.gremlin.structure.Graph} instance. This minimum is determined by the
-     *                      {@link com.tinkerpop.gremlin.structure.Graph} instance itself.
-     * @return A {@link com.tinkerpop.gremlin.structure.Graph} instance.
+     *                      {@link org.apache.tinkerpop.gremlin.structure.Graph} instance. This minimum is determined by the
+     *                      {@link org.apache.tinkerpop.gremlin.structure.Graph} instance itself.
+     * @return A {@link org.apache.tinkerpop.gremlin.structure.Graph} instance.
      * @throws IllegalArgumentException if {@code configuration}
      */
@@ -76,14 +76,14 @@ public class GraphFactory {
 
     /**
-     * Open a graph.  See each {@link com.tinkerpop.gremlin.structure.Graph} instance for its configuration options. This file may be XML, YAML,
+     * Open a graph.  See each {@link org.apache.tinkerpop.gremlin.structure.Graph} instance for its configuration options. This file may be XML, YAML,
      * or a standard properties file. How the configuration is used (and which kind is required) is dependent on
      * the implementation.
@@ -76,14 +76,14 @@ public class GraphFactory {
      *
      * @param configurationFile The location of a configuration file that specifies the minimally required properties
-     *                          for a {@link com.tinkerpop.gremlin.structure.Graph} instance. This minimum is determined by the {@link com.tinkerpop.gremlin.structure.Graph} instance
+     *                          for a {@link org.apache.tinkerpop.gremlin.structure.Graph} instance. This minimum is determined by the {@link org.apache.tinkerpop.gremlin.structure.Graph} instance
      *                          itself.
@@ -92,7 +92,7 @@ public class GraphFactory {
 
     /**
-     * Open a graph. See each {@link com.tinkerpop.gremlin.structure.Graph} instance for its configuration options.
+     * Open a graph. See each {@link org.apache.tinkerpop.gremlin.structure.Graph} instance for its configuration options.
      *
      * @param configuration A {@link java.util.Map} based configuration that will be converted to an {@link org.apache.commons.configuration.Configuration} object
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/StringFactory.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/StringFactory.java
index 0655e16..3c15eb8 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/StringFactory.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/StringFactory.java
@@ -16,27 +16,27 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util;
-
-import com.tinkerpop.gremlin.process.TraversalSideEffects;
-import com.tinkerpop.gremlin.process.TraversalStrategies;
-import com.tinkerpop.gremlin.process.TraversalStrategy;
-import com.tinkerpop.gremlin.process.computer.ComputerResult;
-import com.tinkerpop.gremlin.process.computer.GraphComputer;
-import com.tinkerpop.gremlin.process.computer.MapReduce;
-import com.tinkerpop.gremlin.process.computer.Memory;
-import com.tinkerpop.gremlin.process.computer.VertexProgram;
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.strategy.GraphStrategy;
-import com.tinkerpop.gremlin.structure.strategy.StrategyElement;
-import com.tinkerpop.gremlin.structure.strategy.StrategyProperty;
-import com.tinkerpop.gremlin.structure.strategy.StrategyVariables;
-import com.tinkerpop.gremlin.util.function.FunctionUtils;
+package org.apache.tinkerpop.gremlin.structure.util;
+
+import org.apache.tinkerpop.gremlin.process.TraversalSideEffects;
+import org.apache.tinkerpop.gremlin.process.TraversalStrategies;
+import org.apache.tinkerpop.gremlin.process.TraversalStrategy;
+import org.apache.tinkerpop.gremlin.process.computer.ComputerResult;
+import org.apache.tinkerpop.gremlin.process.computer.GraphComputer;
+import org.apache.tinkerpop.gremlin.process.computer.MapReduce;
+import org.apache.tinkerpop.gremlin.process.computer.Memory;
+import org.apache.tinkerpop.gremlin.process.computer.VertexProgram;
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.strategy.GraphStrategy;
+import org.apache.tinkerpop.gremlin.structure.strategy.StrategyElement;
+import org.apache.tinkerpop.gremlin.structure.strategy.StrategyProperty;
+import org.apache.tinkerpop.gremlin.structure.strategy.StrategyVariables;
+import org.apache.tinkerpop.gremlin.util.function.FunctionUtils;
 import org.javatuples.Pair;
 
 import java.lang.reflect.Method;
@@ -78,14 +78,14 @@ public final class StringFactory {
     }
 
     /**
      * Construct the representation for a {@link com.tinkerpop.gremlin.structure.Vertex}.
      */
     public static String vertexString(final Vertex vertex) {
         return V + L_BRACKET + vertex.id() + R_BRACKET;
     }
 
     /**
      * Construct the representation for a {@link com.tinkerpop.gremlin.structure.Edge}.
      */
     public static String edgeString(final Edge edge) {
         final Vertex inV = edge.iterators().vertexIterator(Direction.IN).next();
@@ -94,7 +94,7 @@ public final class StringFactory {
     }
 
     /**
      * Construct the representation for a {@link com.tinkerpop.gremlin.structure.Property} or {@link com.tinkerpop.gremlin.structure.VertexProperty}.
      */
     public static String propertyString(final Property property) {
         if (property instanceof VertexProperty) {
@@ -109,7 +109,7 @@ public final class StringFactory {
     }
 
     /**
      * Construct the representation for a {@link com.tinkerpop.gremlin.structure.Graph}.
      *
      * @param internalString a mapper {@link String} that appends to the end of the standard representation
      */
@@ -118,7 +118,7 @@ public final class StringFactory {
     }
 
     /**
      * Construct the representation for a {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
      */
 
     public static String graphStrategyString(final GraphStrategy graphStrategy) {

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchFeatures.java
----------------------------------------------------------------------
@@ -78,14 +78,14 @@ public final class StringFactory {
 
     /**
-     * Construct the representation for a {@link com.tinkerpop.gremlin.structure.Vertex}.
+     * Construct the representation for a {@link org.apache.tinkerpop.gremlin.structure.Vertex}.
      */
     public static String vertexString(final Vertex vertex) {
@@ -78,14 +78,14 @@ public final class StringFactory {
 
     /**
-     * Construct the representation for a {@link com.tinkerpop.gremlin.structure.Edge}.
+     * Construct the representation for a {@link org.apache.tinkerpop.gremlin.structure.Edge}.
      */
     public static String edgeString(final Edge edge) {
@@ -94,7 +94,7 @@ public final class StringFactory {
 
     /**
-     * Construct the representation for a {@link com.tinkerpop.gremlin.structure.Property} or {@link com.tinkerpop.gremlin.structure.VertexProperty}.
+     * Construct the representation for a {@link org.apache.tinkerpop.gremlin.structure.Property} or {@link org.apache.tinkerpop.gremlin.structure.VertexProperty}.
      */
     public static String propertyString(final Property property) {
@@ -109,7 +109,7 @@ public final class StringFactory {
 
     /**
-     * Construct the representation for a {@link com.tinkerpop.gremlin.structure.Graph}.
+     * Construct the representation for a {@link org.apache.tinkerpop.gremlin.structure.Graph}.
      *
      * @param internalString a mapper {@link String} that appends to the end of the standard representation
@@ -118,7 +118,7 @@ public final class StringFactory {
 
     /**
-     * Construct the representation for a {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
+     * Construct the representation for a {@link org.apache.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
      */
 
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java
index 4820501..7278db5 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java
@@ -16,24 +16,24 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.batch;
-
-import com.tinkerpop.gremlin.process.T;
-import com.tinkerpop.gremlin.process.Traversal;
-import com.tinkerpop.gremlin.process.computer.GraphComputer;
-import com.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
-import com.tinkerpop.gremlin.process.graph.traversal.VertexTraversal;
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Element;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Transaction;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.VertexProperty;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
-import com.tinkerpop.gremlin.structure.util.batch.cache.VertexCache;
-import com.tinkerpop.gremlin.util.iterator.IteratorUtils;
+package org.apache.tinkerpop.gremlin.structure.util.batch;
+
+import org.apache.tinkerpop.gremlin.process.T;
+import org.apache.tinkerpop.gremlin.process.Traversal;
+import org.apache.tinkerpop.gremlin.process.computer.GraphComputer;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.GraphTraversal;
+import org.apache.tinkerpop.gremlin.process.graph.traversal.VertexTraversal;
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Element;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Transaction;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.VertexProperty;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.util.batch.cache.VertexCache;
+import org.apache.tinkerpop.gremlin.util.iterator.IteratorUtils;
 import org.apache.commons.configuration.BaseConfiguration;
 import org.apache.commons.configuration.Configuration;
 
@@ -54,7 +54,7 @@ import java.util.function.Function;
  * {@code BatchGraph} is ONLY meant for loading data and does not support any retrieval or removal operations.
  * That is, BatchGraph only supports the following methods:
  * - {@link #addVertex(Object...)} for adding vertices
  * - {@link Vertex#addEdge(String, com.tinkerpop.gremlin.structure.Vertex, Object...)} for adding edges
  * - {@link #V(Object...)} to be used when adding edges
  * - Property getter, setter and removal methods for vertices and edges.
  * <br />
@@ -65,13 +65,13 @@ import java.util.function.Function;
  * {@code BatchGraph} can also automatically set the provided element ids as properties on the respective element. Use
  * {@link Builder#vertexIdKey(String)} and {@link Builder#edgeIdKey(String)} to set the keys
  * for the vertex and edge properties respectively. This allows to make the loaded baseGraph compatible for later
  * operation with {@link com.tinkerpop.gremlin.structure.strategy.IdStrategy}.
  * <br/>
  * Note that {@code BatchGraph} itself is not a {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy} because
  * it requires that the {@link Vertex} implementation not hold on to the underlying {@link Vertex} reference and
  * {@link com.tinkerpop.gremlin.structure.strategy.StrategyVertex} does that by it's very nature.  While it might
  * be possible to work around this issue, it is likely better for performance to simply leave this as a "half-wrapper"
  * implementation, instead of forcing it into a {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
  *
  * @author Matthias Broecheler (http://www.matthiasb.com)
  * @author Stephen Mallette (http://stephen.genoprime.com)
@@ -593,7 +593,7 @@ public class BatchGraph<G extends Graph> implements Graph, Graph.Iterators {
         }
 
         /**
          * Number of mutations to perform between calls to {@link com.tinkerpop.gremlin.structure.Transaction#commit}.
          */
         public Builder bufferSize(long bufferSize) {
             if (bufferSize <= 0) throw new IllegalArgumentException("BufferSize must be positive");

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/Exists.java
----------------------------------------------------------------------
@@ -54,7 +54,7 @@ import java.util.function.Function;
  * That is, BatchGraph only supports the following methods:
  * - {@link #addVertex(Object...)} for adding vertices
- * - {@link Vertex#addEdge(String, com.tinkerpop.gremlin.structure.Vertex, Object...)} for adding edges
+ * - {@link Vertex#addEdge(String, org.apache.tinkerpop.gremlin.structure.Vertex, Object...)} for adding edges
  * - {@link #V(Object...)} to be used when adding edges
  * - Property getter, setter and removal methods for vertices and edges.
@@ -65,13 +65,13 @@ import java.util.function.Function;
  * {@link Builder#vertexIdKey(String)} and {@link Builder#edgeIdKey(String)} to set the keys
  * for the vertex and edge properties respectively. This allows to make the loaded baseGraph compatible for later
- * operation with {@link com.tinkerpop.gremlin.structure.strategy.IdStrategy}.
+ * operation with {@link org.apache.tinkerpop.gremlin.structure.strategy.IdStrategy}.
  * <br/>
@@ -65,13 +65,13 @@ import java.util.function.Function;
  * <br/>
- * Note that {@code BatchGraph} itself is not a {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy} because
+ * Note that {@code BatchGraph} itself is not a {@link org.apache.tinkerpop.gremlin.structure.strategy.GraphStrategy} because
  * it requires that the {@link Vertex} implementation not hold on to the underlying {@link Vertex} reference and
@@ -65,13 +65,13 @@ import java.util.function.Function;
  * it requires that the {@link Vertex} implementation not hold on to the underlying {@link Vertex} reference and
- * {@link com.tinkerpop.gremlin.structure.strategy.StrategyVertex} does that by it's very nature.  While it might
+ * {@link org.apache.tinkerpop.gremlin.structure.strategy.StrategyVertex} does that by it's very nature.  While it might
  * be possible to work around this issue, it is likely better for performance to simply leave this as a "half-wrapper"
@@ -65,13 +65,13 @@ import java.util.function.Function;
  * be possible to work around this issue, it is likely better for performance to simply leave this as a "half-wrapper"
- * implementation, instead of forcing it into a {@link com.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
+ * implementation, instead of forcing it into a {@link org.apache.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
  *
  * @author Matthias Broecheler (http://www.matthiasb.com)
@@ -593,7 +593,7 @@ public class BatchGraph<G extends Graph> implements Graph, Graph.Iterators {
 
         /**
-         * Number of mutations to perform between calls to {@link com.tinkerpop.gremlin.structure.Transaction#commit}.
+         * Number of mutations to perform between calls to {@link org.apache.tinkerpop.gremlin.structure.Transaction#commit}.
          */
         public Builder bufferSize(long bufferSize) {
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedEdge.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedEdge.java
index be20e6d..6d78678 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedEdge.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedEdge.java
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package com.tinkerpop.gremlin.structure.util.detached;
-
-import com.tinkerpop.gremlin.process.T;
-import com.tinkerpop.gremlin.structure.Direction;
-import com.tinkerpop.gremlin.structure.Edge;
-import com.tinkerpop.gremlin.structure.Graph;
-import com.tinkerpop.gremlin.structure.Property;
-import com.tinkerpop.gremlin.structure.Vertex;
-import com.tinkerpop.gremlin.structure.util.ElementHelper;
-import com.tinkerpop.gremlin.structure.util.StringFactory;
-import com.tinkerpop.gremlin.util.iterator.IteratorUtils;
+package org.apache.tinkerpop.gremlin.structure.util.detached;
+
+import org.apache.tinkerpop.gremlin.process.T;
+import org.apache.tinkerpop.gremlin.structure.Direction;
+import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Graph;
+import org.apache.tinkerpop.gremlin.structure.Property;
+import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
+import org.apache.tinkerpop.gremlin.util.iterator.IteratorUtils;
 import org.javatuples.Pair;
 
 import java.util.Collections;
@@ -44,7 +44,7 @@ import java.util.NoSuchElementException;
  * A {@code DetachedEdge} only has reference to the properties and in/out vertices that are associated with it at the
  * time of detachment (or construction) and is not traversable or mutable.  Note that the references to the in/out
  * vertices are {@link DetachedVertex} instances that only have reference to the
  * {@link com.tinkerpop.gremlin.structure.Vertex#id()} and {@link com.tinkerpop.gremlin.structure.Vertex#label()}.
  *
  * @author Stephen Mallette (http://stephen.genoprime.com)
  * @author Marko A. Rodriguez (http://markorodriguez.com)

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/detached/DetachedElement.java
----------------------------------------------------------------------
@@ -44,7 +44,7 @@ import java.util.NoSuchElementException;
  * time of detachment (or construction) and is not traversable or mutable.  Note that the references to the in/out
  * vertices are {@link DetachedVertex} instances that only have reference to the
- * {@link com.tinkerpop.gremlin.structure.Vertex#id()} and {@link com.tinkerpop.gremlin.structure.Vertex#label()}.
+ * {@link org.apache.tinkerpop.gremlin.structure.Vertex#id()} and {@link org.apache.tinkerpop.gremlin.structure.Vertex#label()}.
  *
  * @author Stephen Mallette (http://stephen.genoprime.com)